<?php
namespace Drupal\simplifying\Services;
/**
 * Class EntityFields
 *
 * @package Drupal\simplifying
 */
class EntityFields {
  public function FormFields(&$form, $form_state) {
    $types = [
      'nodes'    => t('Node fields', [], ['context' => 'simplifying']),
      'users'    => t('User fields', [], ['context' => 'simplifying']),
      'comments' => t('Comment fields', [], ['context' => 'simplifying']),
      'taxonomy' => t('Taxonomy fields', [], ['context' => 'simplifying']),
      'blocks'   => t('Block fields', [], ['context' => 'simplifying']),
    ];
    foreach ($types as $type => $label) {
      $form[$type.'_wrapper'] = [
        '#type'  => 'details',
        '#title' => $label,
        '#group' => 'tabs',
      ];
      $form[$type.'_wrapper'][$type.'_fields'] = [
        '#type'          => 'checkboxes',
        '#title'         => $label,
        '#title_display' => 'invisible',
        '#parents'       => ['entity_fields', $type],
        '#options'       => $this->GetDefaultFields($type),
        '#default_value' => $this->GetFields($type),
      ];
    }
  }
  public function HideFields(&$form, $type) {
    if (!empty($_COOKIE['simplifying'])) return;
    $fields = $this->GetFields($type);
    foreach ($fields as $field) {
      $this->HideField($form, $field);
      if($field == 'field_comments'){
        $this->HideField($form, 'comment');
      }
    }
  }
  public function HideField(&$form, $field) {
    // Alter to change the list of content fields to be hidden.
    \Drupal::moduleHandler()->alter('simplifying_hide_field', $form, $field);

    if (!isset($form[$field]) && $field != 'format') return;
    if ($field == 'format') {
      $this->HideTextFormatElements($form);
    } elseif ($field == 'path' || $field == 'comment') {
      $form[$field]['widget'][0]['#prefix'] = '<div class="hidden">';
      $form[$field]['widget'][0]['#suffix'] = '</div>';
    } else {
      $form[$field]['#prefix'] = '<div class="hidden">';
      $form[$field]['#suffix'] = '</div>';
    }
  }
  public function HideTextFormatElements(&$form ){
    foreach (\Drupal\Core\Render\Element::children($form) as $key) {
      if (!isset($form[$key]['#type']) || $form[$key]['#type'] == 'container') {
        $this->HideTextFormatElements($form[$key]);
      } elseif ($form[$key]['#type'] == 'text_format') {
        $form[$key]['#after_build'][] = __CLASS__.'::HideTextFormatElement';
      }
    }
  }
  static public function HideTextFormatElement($element){
    if (!empty($element['format'])) {
      $element['format']['#prefix'] = '<div class="hidden">';
      $element['format']['#suffix'] = '</div>';
    }
    return $element;
  }
  public function GetFields($type){
    $fields = \Drupal::service('simplifying.settings')->GetSettings('entity_fields');
    if (isset($fields[$type])) {
      $fields = $fields[$type];
    } else {
      $fields = $this->GetDefaultFields($type);
      if (!empty($fields)) $fields = array_keys($fields);
    }
    return $fields;
  }
  public function GetDefaultFields($type) {
    $fields = [];
    switch ($type) {
      // Nodes.
      case 'nodes':
        $fields['author'] = t('Authoring information', [], ['context' => 'simplifying']);
        $fields['format'] = t('Text format selection', [], ['context' => 'simplifying']);
        $fields['options'] = t('Promotion options', [], ['context' => 'simplifying']);
        $fields['revision_information'] = t('Revision information', [], ['context' => 'simplifying']);
        $fields['url_redirects'] = t('Url redirects', [], ['context' => 'simplifying']);
        if (\Drupal::moduleHandler()->moduleExists('menu_ui')) {
          $fields['menu'] = t('Menu settings', [], ['context' => 'simplifying']);
        }
        if (\Drupal::moduleHandler()->moduleExists('path')) {
          $fields['path'] = t('URL path settings', [], ['context' => 'simplifying']);
        }
        if (\Drupal::moduleHandler()->moduleExists('simple_sitemap')) {
          $fields['simple_sitemap'] = t('XML sitemap', [], ['context' => 'simplifying']);
        }
        if (\Drupal::moduleHandler()->moduleExists('drupal_seo')) {
          $fields['drupal_seo'] = t('Drupal seo', [], ['context' => 'simplifying']);
        }
        $fields['field_comments'] = t('Comments', [], ['context' => 'simplifying']);
      break;
      // Users.
      case 'users':
        $fields['format'] = t('Text format selection', [], ['context' => 'simplifying']);
        $fields['status'] = t('Status (blocked/active)', [], ['context' => 'simplifying']);
        $fields['notify'] = t('User notify', [], ['context' => 'simplifying']);
        $fields['roles'] = t('User roles', [], ['context' => 'simplifying']);
        if (\Drupal::moduleHandler()->moduleExists('path')) {
          $fields['path'] = t('URL path settings', [], ['context' => 'simplifying']);
        }
      break;
      // Comments.
      case 'comments':
        $fields['format'] = t('Text format selection', [], ['context' => 'simplifying']);
      break;
      // Taxonomy.
      case 'taxonomy':
        $fields['format'] = t('Text format selection', [], ['context' => 'simplifying']);
        $fields['relations'] = t('Parents', [], ['context' => 'simplifying']);
        if (\Drupal::moduleHandler()->moduleExists('path')) {
          $fields['path'] = t('URL path settings', [], ['context' => 'simplifying']);
        }
        if (\Drupal::moduleHandler()->moduleExists('simple_sitemap')) {
          $fields['simple_sitemap'] = t('XML sitemap', [], ['context' => 'simplifying']);
        }
        if (\Drupal::moduleHandler()->moduleExists('tvi')) {
          $fields['tvi'] = t('Tvi', [], ['context' => 'simplifying']);
        }
      break;
      // Blocks.
      case 'blocks':
        $fields['format'] = t('Text format selection', [], ['context' => 'simplifying']);
        $fields['revision_information'] = t('Revision information', [], ['context' => 'simplifying']);
      break;
    }
    
    // Alter hide form fields.
    \Drupal::moduleHandler()->alter('simplifying_get_fields', $fields, $type);
    return $fields;
  }
}