<?php
namespace Drupal\simplifying\Services;
/**
 * Class Toolbar
 *
 * @package Drupal\simplifying
 */
class Toolbar {
  public function FormFields(&$form, $form_state) {
    $form['toolbar_design_wrapper'] = [
      '#type'  => 'details',
      '#title' => t('Toolbar design', [], ['context' => 'simplifying']),
      '#group' => 'tabs',
    ];
    $defs = \Drupal::service('simplifying.settings')->GetSettings('design');

    $form['toolbar_design_wrapper']['small_button'] = [
      '#type'          => 'checkbox',
      '#title'         => t('Small button', [], ['context' => 'simplifying']),
      '#parents'       => ['design', 'small_button'],
      '#default_value' => !empty($defs['small_button']) ? 1 : 0,
    ];
    $form['toolbar_design_wrapper']['top_background'] = [
      '#type'          => 'color',
      '#title'         => t('Top menu background', [], ['context' => 'simplifying']),
      '#parents'       => ['design', 'top_background'],
      '#default_value' => !empty($defs['top_background']) ? $defs['top_background'] : '#3A9F00',
    ];
    $form['toolbar_design_wrapper']['top_color'] = [
      '#type'          => 'color',
      '#title'         => t('Top menu color', [], ['context' => 'simplifying']),
      '#parents'       => ['design', 'top_color'],
      '#default_value' => !empty($defs['top_color']) ? $defs['top_color'] : '#000000',
    ];
    $form['toolbar_design_wrapper']['submenu_background'] = [
      '#type'          => 'color',
      '#title'         => t('Submenu background', [], ['context' => 'simplifying']),
      '#parents'       => ['design', 'submenu_background'],
      '#default_value' => !empty($defs['submenu_background']) ? $defs['submenu_background'] : '#555555',
    ];

    $form['toolbar_tabs_wrapper'] = [
      '#type'  => 'details',
      '#title' => t('Toolbar tabs', [], ['context' => 'simplifying']),
      '#group' => 'tabs',
    ];
    $form['toolbar_tabs_wrapper']['toolbar_tabs'] = [
      '#type'          => 'checkboxes',
      '#title'         => t('Toolbar tabs', [], ['context' => 'simplifying']),
      '#title_display' => 'invisible',
      '#options'       => $this->GetDefaultToolbarTabs(),
      '#default_value' => $this->GetToolbarTabs(),
    ];

    $menu_tree_parameters = new \Drupal\Core\Menu\MenuTreeParameters();
    $tree = \Drupal::menuTree()->load('admin', $menu_tree_parameters);
    $manipulators = [
      ['callable' => 'menu.default_tree_manipulators:generateIndexAndSort'],
    ];
    $tree = \Drupal::menuTree()->transform($tree, $manipulators);
    $options = [];
    $this->TreeOptions($tree, $options);
    $defs = \Drupal::service('simplifying.settings')->GetSettings('menu_links');

    $form['menu_links'] = [
      '#type'  => 'details',
      '#title' => t('Menu links', [], ['context' => 'simplifying']),
      '#group' => 'tabs',
    ];

    foreach ($options as $val) {
      $form['menu_links'][ $val['path'] ] = [
        '#prefix'  => \Drupal\Core\Render\Markup::create('<div style="padding-left: '.(($val['depth'] - 1) * 20).'px;">'),
        '#suffix'  => '</div>',
        '#type'    => 'checkbox',
        '#parents' => ['menu_links', $val['path']],
        '#title'   => $val['title'],
      ];
      if (in_array($val['path'], $defs)) {
        $form['menu_links'][ $val['path'] ]['#default_value'] = 1;
      }
    }
  }
  public function TreeOptions($tree, &$options) {
    if (isset($tree['system.admin'])) $tree = ['system.admin' => $tree['system.admin']];
    foreach ($tree as $rout => $val) {
      if (!empty($val->link)) {
        $link = $val->link;
        $path = \Drupal\Core\Url::fromRoute($link->getRouteName(), $link->getRouteParameters(), $link->getOptions())->getInternalPath();
        if(!empty($path)){
          $title = $link->getTitle();
          $options[$rout] = ['title' => $title, 'depth' => $val->depth, 'path' => $path, 'rout' => $rout];
        }
      }
      if (!empty($val->subtree)) {
        $this->TreeOptions($val->subtree, $options);
      }
    }
  }
  public function Toolbar(&$items) {
    $design = \Drupal::service('simplifying.settings')->GetSettings('design');
    $route_name = \Drupal::routeMatch()->getRouteName();

    $class = ['toolbar-icon', 'toolbar-icon-simplifying_switch'];
    $text = t('Full administration', [], ['context' => 'simplifying']);
    if (!empty($_COOKIE['simplifying'])) {
      $class[] = 'is-active';
      $text = t('Small administration', [], ['context' => 'simplifying']);
    }
    $items['simplifying'] = [
      '#type'               => 'toolbar_item',
      '#wrapper_attributes' => [
        'class' => ['toolbar_simplifying', 'toolbar_simplifying_switch']
      ],
      '#attached'           => [
        'library' => [ 'simplifying/simplifying' ]
      ],
      '#weight'             => -50,
      'tab'                 => [
        '#type'       => 'html_tag',
        '#tag'        => 'button',
        '#value'      => $text,
        '#attributes' => [
          'class'   => $class,
          'onclick' => 'SimplifyingSwitch(this)',
        ],
      ],
    ];
    if (!empty($design['small_button'])) {
      $items['simplifying']['tab']['#attributes']['class'][] = 'small_button';
      $items['simplifying']['tab']['#attributes']['title'] = $text;
    }

    $items['simplifying']['#attached']['drupalSettings']['simplifying_menu_links'] = \Drupal::service('simplifying.settings')->GetSettings('menu_links');

    $toolbar_tabs = $this->GetToolbarTabs();
    // Alter to hide the toolbar tabs.
    \Drupal::moduleHandler()->alter('simplifying_hide_toolbar_tabs', $toolbar_tabs);

    $items['simplifying']['#attached']['drupalSettings']['simplifying_menu_tabs'] = $toolbar_tabs;

    $styles = [];
    if (!empty($design['top_background'])) {
      $styles[] = '#toolbar-bar{ background-color: '.$design['top_background'].'; }';
    }
    if (!empty($design['top_color'])) {
      $styles[] = '.toolbar .toolbar-bar .toolbar-item{ color: '.$design['top_color'].'; }';
    }
    if (!empty($design['submenu_background'])) {
      $styles[] = '#toolbar-item-administration-tray{ background-color: '.$design['submenu_background'].'; }';
    }
    if (!empty($styles)) {
      $items['simplifying']['tab']['#suffix'] = \Drupal\Core\Render\Markup::create('<style>'.implode($styles).'</style>');
    }

    $class = ['toolbar-icon', 'toolbar-icon-simplifying_services'];
    if ($route_name == 'simplifying.services') {
      $class[] = 'is-active';
    }
    $text = t('Order additional services', [], ['context' => 'simplifying']);
    $items['services'] = [
      '#type'               => 'toolbar_item',
      '#wrapper_attributes' => [
        'class' => ['toolbar_simplifying', 'toolbar_simplifying_services'],
      ],
      '#weight'             => -49,
      'tab'                 => [
        '#type'       => 'link',
        '#title'      => $text,
        '#url'        => \Drupal\Core\Url::fromRoute('simplifying.services'),
        '#attributes' => [ 'class'   => $class ],
      ],
    ];
    if (!empty($design['small_button'])) {
      $items['services']['tab']['#attributes']['class'][] = 'small_button';
      $items['services']['#wrapper_attributes']['title'] = $text;
    }

    $class = ['toolbar-icon', 'toolbar-icon-simplifying_training'];
    if($route_name == 'simplifying.training'){
      $class[] = 'is-active';
    }
    $text = t('Training', [], ['context' => 'simplifying']);
    $items['training'] = [
      '#type'               => 'toolbar_item',
      '#wrapper_attributes' => [
        'class' => ['toolbar_simplifying', 'toolbar_simplifying_training'],
      ],
      '#weight'             => -48,
      'tab'                 => [
        '#type'       => 'link',
        '#title'      => $text,
        '#url'        => \Drupal\Core\Url::fromRoute('simplifying.training'),
        '#attributes' => [ 'class'   => $class ],
      ],
    ];
    if (!empty($design['small_button'])) {
      $items['training']['tab']['#attributes']['class'][] = 'small_button';
      $items['training']['#wrapper_attributes']['title'] = $text;
    }
  }
  public function GetToolbarTabs(){
    $toolbar_tabs = \Drupal::service('simplifying.settings')->GetSettings('toolbar_tabs');
    if (empty($toolbar_tabs)) {
      $toolbar_tabs = ['devel'];
    }
    return array_filter($toolbar_tabs);
  }
  public function GetDefaultToolbarTabs() {
    return [
      'home'           => t('Back to site', [], ['context' => 'simplifying']),
      'administration' => t('Manage', [], ['context' => 'simplifying']),
      'shortcuts'      => t('Shortcuts', [], ['context' => 'simplifying']),
      'user'           => t('User', [], ['context' => 'simplifying']),
      'devel'          => t('Devel', [], ['context' => 'simplifying']),
      'contextual'     => t('Edit', [], ['context' => 'simplifying']),
    ];
  }
}